@@ -2,7 +2,7 @@
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
  * Copyright (C) 2017-2019, Mathieu Schroeter
- * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
+ * https://epsitec.ch; https://www.blupi.org; https://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include <vector>
 
 #include <SDL_image.h>
+#include <SDL_ttf.h>
 #include <argagg/argagg.hpp>
 #ifdef USE_CURL
 #include <curl/curl.h>
@@ -51,6 +52,7 @@
 #include "platform.h"
 #include "progress.h"
 #include "sound.h"
+#include "text.h"
 
 // Global variables
 
@@ -364,8 +366,7 @@ HandleEvent (const SDL_Event & event)
 
   switch (event.type)
   {
-  case SDL_WINDOWEVENT:
-  {
+  case SDL_WINDOWEVENT: {
 #ifndef DEBUG
     Point totalDim, iconDim;
 
@@ -431,8 +432,7 @@ HandleEvent (const SDL_Event & event)
     g_pEvent->LoadBackground ();
     break;
 
-  case SDL_USEREVENT:
-  {
+  case SDL_USEREVENT: {
     switch (event.user.code)
     {
     case EV_UPDATE:
@@ -448,8 +448,7 @@ HandleEvent (const SDL_Event & event)
       }
       break;
 
-    case EV_WARPMOUSE:
-    {
+    case EV_WARPMOUSE: {
       const SDL_Point * coord = static_cast<SDL_Point *> (event.user.data1);
 
       Sint32 x = coord->x, y = coord->y;
@@ -459,8 +458,7 @@ HandleEvent (const SDL_Event & event)
       break;
     }
 
-    case EV_CHECKUPDATE:
-    {
+    case EV_CHECKUPDATE: {
       std::string * data = static_cast<std::string *> (event.user.data1);
 
       using json    = nlohmann::json;
@@ -471,7 +469,7 @@ HandleEvent (const SDL_Event & event)
       std::vector<unsigned int> version (3);
       std::transform (
         list.begin (), list.end (), version.begin (),
-        [](const std::string & s) -> unsigned int { return std::stoi (s); });
+        [] (const std::string & s) -> unsigned int { return std::stoi (s); });
 
       if (
         (!!PB_VERSION_EXTRA[0] &&
@@ -801,6 +799,14 @@ DoInit (int argc, char * argv[], bool & exit)
     return EXIT_FAILURE;
   }
 
+  if (TTF_Init () < 0)
+  {
+    SDL_Log ("Couldn't initialize TTF: %s", SDL_GetError ());
+    return EXIT_FAILURE;
+  }
+
+  GetFonts ();
+
   if (!(g_settingsOverload & SETTING_LEGACY))
     Display::getDisplay ().readDisplaySize ();
 
@@ -1013,7 +1019,7 @@ DoInit (int argc, char * argv[], bool & exit)
   }
 
   totalDim.x = DIMLITTLEX * 16;
-  totalDim.y = DIMLITTLEY * 16;
+  totalDim.y = DIMLITTLEY * 19;
   iconDim.x  = DIMLITTLEX;
   iconDim.y  = DIMLITTLEY;
   if (!g_pPixmap->Cache (CHLITTLE, "little.png", totalDim, iconDim))
@@ -1110,6 +1116,7 @@ main (int argc, char * argv[])
 
   Platform::run (HandleEvent);
 
+  DisposeFonts ();
   FinishObjects ();
 
   if (g_renderer)
