@@ -2,7 +2,7 @@
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
  * Copyright (C) 2017-2018, Mathieu Schroeter
- * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
+ * https://epsitec.ch; https://www.blupi.org; https://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1915,9 +1915,8 @@ CDecor::CelOkForAction (
       cel.x--;
       cel.y--;
 
-      if (
-        !bStrong || bTransport || bVehicule ||
-        m_blupi[rank].perso == 8) // disciple ?
+      if (!bStrong || bTransport || bVehicule || m_blupi[rank].perso == 8) // disciple
+                                                                           // ?
       {
         error = Errors::MISC; // pas assez fort
       }
@@ -1970,9 +1969,8 @@ CDecor::CelOkForAction (
       cel.x--;
       cel.y--;
 
-      if (
-        !bStrong || bTransport || bVehicule ||
-        m_blupi[rank].perso == 8) // disciple ?
+      if (!bStrong || bTransport || bVehicule || m_blupi[rank].perso == 8) // disciple
+                                                                           // ?
       {
         error = Errors::MISC; // pas assez fort
       }
