@@ -2,7 +2,7 @@
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
  * Copyright (C) 2017-2018, Mathieu Schroeter
- * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
+ * https://epsitec.ch; https://www.blupi.org; https://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@
 #define DIMTEXTY        16
 
 #define DIMLITTLEX      16      // max small char size
-#define DIMLITTLEY      12
+#define DIMLITTLEY      16
 
 #define CHBACK          0
 #define CHFLOOR         1
@@ -306,6 +306,7 @@ enum Sounds {
   SOUND_ARMURECLOSE = 82,
   SOUND_WIN         = 83,
   SOUND_LOST        = 84,
+  SOUND_COUPSEC2    = 85,
 };
 
 // Buttons (play):
