@@ -2,7 +2,7 @@
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
  * Copyright (C) 2017-2019, Mathieu Schroeter
- * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
+ * https://epsitec.ch; https://www.blupi.org; https://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -123,6 +123,49 @@ CPixmap::CreateMainTexture ()
   SDL_SetHint (SDL_HINT_RENDER_SCALE_QUALITY, "nearest");
 }
 
+Sint32
+CPixmap::Blit (
+  Sint32 dstCh, SDL_Texture * src, const SDL_Rect & dstRect, double angle,
+  SDL_RendererFlip flip)
+{
+  Sint32 res;
+  auto   target = SDL_GetRenderTarget (g_renderer);
+
+  if (dstCh < 0)
+  {
+    if (!this->mainTexture && g_bFullScreen && g_zoom == 1)
+    {
+      SDL_SetHint (
+        SDL_HINT_RENDER_SCALE_QUALITY, g_renderQuality ? "best" : "nearest");
+      this->mainTexture = SDL_CreateTexture (
+        g_renderer, SDL_PIXELFORMAT_RGBA32, SDL_TEXTUREACCESS_TARGET,
+        LXIMAGE (), LYIMAGE ());
+      SDL_SetHint (SDL_HINT_RENDER_SCALE_QUALITY, "nearest");
+    }
+    else if (this->mainTexture && !(g_bFullScreen && g_zoom == 1))
+    {
+      SDL_DestroyTexture (this->mainTexture);
+      this->mainTexture = nullptr;
+    }
+
+    if (this->mainTexture)
+      SDL_SetRenderTarget (g_renderer, target ? target : this->mainTexture);
+    res = SDL_RenderCopyEx (
+      g_renderer, src, nullptr, &dstRect, angle, nullptr, flip);
+    if (this->mainTexture)
+      SDL_SetRenderTarget (g_renderer, target);
+  }
+  else
+  {
+    SDL_SetRenderTarget (g_renderer, m_SDLTextureInfo[dstCh].texture);
+    res = SDL_RenderCopyEx (
+      g_renderer, src, nullptr, &dstRect, angle, nullptr, flip);
+    SDL_SetRenderTarget (g_renderer, target);
+  }
+
+  return res;
+}
+
 Sint32
 CPixmap::BltFast (
   Sint32 dstCh, size_t srcCh, Rect dstR, Rect srcR, SDL_RendererFlip flip)
@@ -392,8 +435,7 @@ CPixmap::Cache (
   switch (mode)
   {
   case FIX:
-  case FIX_REVERSABLE:
-  {
+  case FIX_REVERSABLE: {
     if (channel == CHBACK && (ow < LXIMAGE () || oh < LYIMAGE ()))
     {
       if (!wideName.empty ())
@@ -423,8 +465,7 @@ CPixmap::Cache (
   }
 
   case EXPAND:
-  case EXPAND_REVERSABLE:
-  {
+  case EXPAND_REVERSABLE: {
     auto isFlipped = flip == SDL_FLIP_HORIZONTAL;
 
     SDL_Rect src, dst;
